@@ -1,6 +1,9 @@
 test_that("read_dpkg() and read_dpkg_metadata() works", {
   d <- as_dpkg(mtcars, version = "0.1.0", title = "Motor Trend Road Car Tests")
-  attr(d, "description") <- "This is a data set all about characteristics of different cars"
+  attr(
+    d,
+    "description"
+  ) <- "This is a data set all about characteristics of different cars"
   attr(d, "homepage") <- "https://github.com/cole-brokamp/dpkg"
 
   out <- write_dpkg(d, dir = tempdir())
@@ -19,19 +22,29 @@ test_that("read_dpkg() and read_dpkg_metadata() works", {
   the_md$created <- NULL
   expect_true(as.numeric(the_md$file_size) - 7424 < 11)
   the_md$file_size <- NULL
+  the_md$hash <- NULL
   the_md |>
     expect_identical(
       list(
-        name = "mtcars", version = "0.1.0",
+        name = "mtcars",
+        version = "0.1.0",
         title = "Motor Trend Road Car Tests",
         homepage = "https://github.com/cole-brokamp/dpkg",
         description = "This is a data set all about characteristics of different cars",
-        hash = "502c9e71f62f79debf7e769e071df0b4",
         num_rows = 32L,
         num_cols = 11L,
         fields = c(
-          "mpg", "cyl", "disp", "hp", "drat",
-          "wt", "qsec", "vs", "am", "gear", "carb"
+          "mpg",
+          "cyl",
+          "disp",
+          "hp",
+          "drat",
+          "wt",
+          "qsec",
+          "vs",
+          "am",
+          "gear",
+          "carb"
         )
       )
     )
